function Y = uq_undampedOscillator(X)
% UQ_UNDAMPEDOSCILLATOR computes the Undamped (Gayton) oscillator performance
% function.
%
%   Y = UQ_UNDAMPEDOSCILLATOR(X) evaluates the response of the performance
%   function for N-by-6 input matrix X, where N is the number of evaluation
%   points. The function returns a column vector of length N.
% 
%   The input vecttor is composed as:
%        X = {C_1, C_2, M, R, F_1, T_1},
%   where:
%        C_1 is the first spring constant
%        C_2 is the second spring constant
%        M   is the oscillator mass
%        R   is the Yield displacement
%        F_1 is the force acting on oscillator
%        F_2 is the time interval the force is acting on the oscillator
%
%   Reference:
%
% - Echard, B., Gayton, N., Lemaire, M., Relun, N. A combined Importance
%   Sampling and Kriging reliability method for small failure probabilities
%   with time-demanding numerical models, Reliability Engineering & System
%   Safety, vol. 111, pp. 232-240, 2013. DOI:10.1016/j.ress.2012.10.008

%% Check inputs
narginchk(1,1)
assert(size(X,2)==6,'Only 6 input variables are allowed!')

% First spring constant [-]
C_1 = X(:,1);

% Second spring constant [-]
C_2 = X(:,2);

% Oscillator mass [-]
M = X(:,3); 

% Displacement at which the first spring yields [-]
R = X(:,4); 

% Force acting on oscillator [-]
F_1 = X(:,5);

% Period the force is acting on the oscillator [-]
T_1 = X(:,6);

%% Intermediate evaluations

% Natural frequency of oscillator
omega_0 = sqrt((C_1 + C_2)./M); 

%% Evaluation of the performance function
Y = 3*R - abs(2*F_1./(M.*omega_0.^2).*sin(omega_0.*T_1/2));
